package com.ruoyi.system.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.system.domain.InfoUser;

/**
 * 用户信息Service接口
 * 
 * @author ruoyi
 * @date 2023-06-25
 */
public interface IInfoUserService extends IService<InfoUser>
{
    //判断用户是否存在
    InfoUser getinfouserName(String userName);

    //判断手机是否存在
    InfoUser getinfoPhone(String phone);

    InfoUser getuser(String phone);
    /**
     * 查询用户信息
     * 
     * @param userId 用户信息主键
     * @return 用户信息
     */
    public InfoUser selectInfoUserByUserId(Long userId);

    /**
     * 查询用户信息列表
     * 
     * @param infoUser 用户信息
     * @return 用户信息集合
     */
    public List<InfoUser> selectInfoUserList(InfoUser infoUser);

    /**
     * 新增用户信息
     * 
     * @param infoUser 用户信息
     * @return 结果
     */
    public int insertInfoUser(InfoUser infoUser);

    /**
     * 修改用户信息
     * 
     * @param infoUser 用户信息
     * @return 结果
     */
    public int updateInfoUser(InfoUser infoUser);

    /**
     * 批量删除用户信息
     * 
     * @param userIds 需要删除的用户信息主键集合
     * @return 结果
     */
    public int deleteInfoUserByUserIds(Long[] userIds);

    /**
     * 删除用户信息信息
     * 
     * @param userId 用户信息主键
     * @return 结果
     */
    public int deleteInfoUserByUserId(Long userId);
}
